@@ -1,5 +1,5 @@
 """
-Advanced features example for the Alchemist Python SDK.
+Advanced features example for the Olbrain Python SDK.
 
 This example demonstrates:
 - Context manager usage
@@ -14,8 +14,8 @@ import time
 import logging
 from typing import Dict, Any
 from contextlib import contextmanager
-from alchemist import AgentClient
-from alchemist.exceptions import AlchemistError
+from olbrain import AgentClient
+from olbrain.exceptions import OlbrainError
 
 
 # Configure logging for performance monitoring
@@ -32,7 +32,7 @@ def timer(operation_name: str):
     logger.info(f"{operation_name} took {end_time - start_time:.2f} seconds")
 
 
-class AdvancedAlchemistClient:
+class AdvancedOlbrainClient:
     """Extended client with additional features."""
     
     def __init__(self, agent_id: str, api_key: str, **kwargs):
@@ -100,15 +100,15 @@ def demonstrate_context_manager_usage():
     print("🎯 Context Manager Usage")
     print("=" * 60)
     
-    api_key = os.getenv("ALCHEMIST_API_KEY", "demo-key")
-    agent_id = os.getenv("ALCHEMIST_AGENT_ID", "demo-agent")
+    api_key = os.getenv("OLBRAIN_API_KEY", "demo-key")
+    agent_id = os.getenv("OLBRAIN_AGENT_ID", "demo-agent")
     
     if api_key == "demo-key":
         print("⚠️ Skipping context manager demo - no valid API key")
         return
     
     # Using the client as a context manager ensures proper cleanup
-    with AlchemistClient(api_key=api_key) as client:
+    with AgentClient(api_key=api_key) as client:
         print("✅ Client initialized in context manager")
         
         try:
@@ -135,7 +135,7 @@ def demonstrate_custom_configuration():
     print("⚙️ Custom Configuration")
     print("=" * 60)
     
-    api_key = os.getenv("ALCHEMIST_API_KEY", "demo-key")
+    api_key = os.getenv("OLBRAIN_API_KEY", "demo-key")
     
     # Configuration for high-performance usage
     high_perf_config = {
@@ -161,11 +161,11 @@ def demonstrate_custom_configuration():
         # Demonstrate different configurations
         try:
             # Test with quick config
-            with AlchemistClient(api_key=api_key, **quick_config) as quick_client:
+            with AgentClient(api_key=api_key, **quick_config) as quick_client:
                 print("\n✅ Quick client initialized")
                 
             # Test with high-performance config
-            with AlchemistClient(api_key=api_key, **high_perf_config) as hp_client:
+            with AgentClient(api_key=api_key, **high_perf_config) as hp_client:
                 print("✅ High-performance client initialized")
                 
         except Exception as e:
@@ -180,15 +180,15 @@ def demonstrate_metadata_handling():
     print("📊 Metadata Handling")
     print("=" * 60)
     
-    api_key = os.getenv("ALCHEMIST_API_KEY", "demo-key")
-    agent_id = os.getenv("ALCHEMIST_AGENT_ID", "demo-agent")
+    api_key = os.getenv("OLBRAIN_API_KEY", "demo-key")
+    agent_id = os.getenv("OLBRAIN_AGENT_ID", "demo-agent")
     
     if api_key == "demo-key":
         print("⚠️ Skipping metadata demo - no valid API key")
         return
     
     try:
-        with AlchemistClient(api_key=api_key) as client:
+        with AgentClient(api_key=api_key) as client:
             agent = client.get_agent(agent_id)
             
             # Create session with rich metadata
@@ -279,8 +279,8 @@ def demonstrate_performance_monitoring():
     print("📈 Performance Monitoring")
     print("=" * 60)
     
-    api_key = os.getenv("ALCHEMIST_API_KEY", "demo-key")
-    agent_id = os.getenv("ALCHEMIST_AGENT_ID", "demo-agent")
+    api_key = os.getenv("OLBRAIN_API_KEY", "demo-key")
+    agent_id = os.getenv("OLBRAIN_AGENT_ID", "demo-agent")
     
     if api_key == "demo-key":
         print("⚠️ Skipping performance monitoring demo - no valid API key")
@@ -288,7 +288,7 @@ def demonstrate_performance_monitoring():
     
     try:
         # Use our extended client with metrics
-        extended_client = AdvancedAlchemistClient(api_key=api_key)
+        extended_client = AdvancedAgentClient(api_key=api_key)
         agent = extended_client.get_agent_with_metrics(agent_id)
         
         print("🚀 Running performance test with metrics collection...")
@@ -351,15 +351,15 @@ def demonstrate_advanced_session_management():
     print("💼 Advanced Session Management")
     print("=" * 60)
     
-    api_key = os.getenv("ALCHEMIST_API_KEY", "demo-key")
-    agent_id = os.getenv("ALCHEMIST_AGENT_ID", "demo-agent")
+    api_key = os.getenv("OLBRAIN_API_KEY", "demo-key")
+    agent_id = os.getenv("OLBRAIN_AGENT_ID", "demo-agent")
     
     if api_key == "demo-key":
         print("⚠️ Skipping advanced session demo - no valid API key")
         return
     
     try:
-        with AlchemistClient(api_key=api_key) as client:
+        with AgentClient(api_key=api_key) as client:
             agent = client.get_agent(agent_id)
             
             # Create multiple sessions with different purposes
@@ -453,7 +453,7 @@ def demonstrate_advanced_session_management():
 
 def main():
     """Run all advanced feature demonstrations."""
-    print("🚀 Alchemist SDK Advanced Features Examples")
+    print("🚀 Olbrain SDK Advanced Features Examples")
     print("This demo showcases advanced usage patterns and features.\n")
     
     demonstrate_context_manager_usage()
